# Suspect Citizens Update
# Chapter 3
# Alex Love
# July 25, 2021

library(tidyverse)
library(ggplot2)
library(haven)
library(fuzzyjoin)
library(sf)

#load population data
ncpop <- read.csv("ncpop.csv")
ncpop$name <- str_split_fixed(ncpop$Geographic.Area.Name,",",2)[,1]

#load traffic stops data
fullset <- read_dta("/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta")

#race
fullset$black_stop= ifelse(fullset$race2==2,1,0)
fullset$white_stop= ifelse(fullset$race2==1,1,0)
fullset$hisp_stop= ifelse(fullset$race2==3,1,0)
fullset$other_stop= ifelse(fullset$race2==4,1,0)

#Table 3.2
#collapse 
stops <- fullset %>%
  group_by(year) %>%
  summarize(black= sum(black_stop, na.rm=T),
            white= sum(white_stop, na.rm=T), 
            hisp=sum(hisp_stop, na.rm=T),
            other=sum(other_stop, na.rm =T),
            n=n()) %>%
  mutate(wht_rate=white/n,
         blk_rate=black/n,
         hisp_rate=hisp/n,
         other_rate=other/n) %>%
  select(year, wht_rate, blk_rate, hisp_rate, other_rate)%>%
  gather(., race, measurement, wht_rate:other_rate, factor_key = TRUE)


#plot
ggplot(stops, aes(x=year, y=measurement, group=race))+
  geom_line(aes(linetype=race))+
  scale_linetype_manual(values = c("solid", "dashed", "dotted", "dotdash"),
                        labels=c("White", "Black", "Hispanic", "Other")) +
  theme_classic()+
  theme(legend.position = "bottom", 
        legend.background = element_rect(linetype = 1, size = 0.5, colour = 1),
        legend.title = element_blank()) +
  ylab("Percentage of Stops")+
  xlab("Year")

#Figure 3.3
stops <- fullset %>%
  group_by(agencydescription, agencyid, year) %>%
  summarize(black= sum(black_stop, na.rm=T),
            white= sum(white_stop, na.rm=T), 
            hisp=sum(hisp_stop, na.rm=T),
            other=sum(other_stop, na.rm =T),
            n=n()) %>%
  mutate(blk_rate=black/n,
         wht_rate=white/n,
         hisp_rate=hisp/n,
         other_rate=other/n) %>%
  select(agencydescription, agencyid, year, blk_rate, wht_rate, hisp_rate, other_rate)

#list each agency
key <- fullset %>%
  distinct(agencydescription, agencyid)

#Do this to help with matching
key <- data.frame(lapply(key, function(x){
  gsub("Sheriff's Office", "",x)
}))
key <- data.frame(lapply(key, function(x){
  gsub("Police Department", "Town",x)
}))

# Remove hospitals and univerisities
key <- (key[!grepl("University", key$agencydescription),])
key <- (key[!grepl("UNC", key$agencydescription),])
key <- (key[!grepl("Hospital", key$agencydescription),])

key <- key %>%
  rename("name"=agencydescription)

#fuzzy match
look <- stringdist_join(key, ncpop, 
                by = "name",
                mode = "left",
                ignore_case = FALSE, 
                method = "jw", 
                max_dist = .35, 
                distance_col = "dist") %>%
  group_by(name.x) %>%
  slice_min(order_by = dist, n = 1)

idmatch <- look %>%
  select(agencyid, Geographic.Area.Name)

popmatch <- left_join(idmatch, ncpop) %>%
  select(agencyid, pct_wht, pct_black, pct_hispanic, total)%>%
  mutate(agencyid=as.numeric(agencyid))

#merge
plotready <- left_join(stops, popmatch)
plotready[,c(4:7,9:11)] <- sapply(plotready[,c(4:7,9:11)], as.numeric)
plotready$wht_rate <- plotready$wht_rate*100
plotready$blk_rate <- plotready$blk_rate*100
plotready$hisp_rate <- plotready$hisp_rate*100

#plot
#white
ggplot(plotready, aes(x=pct_wht, y=wht_rate, size=total))+
  geom_point(shape=1)+
  scale_size(range = c(.01,13), name="Population")+
  geom_abline()+
  theme_classic()+
  theme(legend.position = "none", panel.border = element_rect(colour="black", fill=NA, size=1))+
  ylab("Percent of Stops")+
  xlab("Percent of the Community")+
  scale_x_continuous(breaks = seq(0,100,20), limits = c(0,100))+
  scale_y_continuous(breaks = seq(0,100,20))


#black
ggplot(plotready, aes(x=pct_black, y=blk_rate, size=total))+
  geom_point(shape=1)+
  scale_size(range = c(.01,13), name="Population")+
  geom_abline()+
  theme_classic()+
  theme(legend.position = "none", panel.border = element_rect(colour="black", fill=NA, size=1))+
  ylab("Percent of Stops")+
  xlab("Percent of the Community")+
  scale_x_continuous(breaks = seq(0,100,20), limits = c(0,100))+
  scale_y_continuous(breaks = seq(0,100,20))



#hispanic
plotready$hisp_rate <- ifelse(plotready$hisp_rate>50,NA,plotready$hisp_rate)
ggplot(plotready, aes(x=pct_hispanic, y=hisp_rate, size=total))+
  geom_point(shape=1)+
  scale_size(range = c(.01,13), name="Population")+
  geom_abline()+
  theme_classic()+
  theme(legend.position = "none", panel.border = element_rect(colour="black", fill=NA, size=1))+
  ylab("Percent of Stops")+
  xlab("Percent of the Community")+
  xlim(0,40) +
  ylim(0,40)


#TABLE 3.1
ncpop<- ncpop[ncpop$id!="0100000US",]

ncpop %>%
  summarize(totalpop=sum(total),
            wht_pop=sum(white),
            blk_pop=sum(black),
            hisp_pop=sum(hispanic))

fullset %>%
  filter(year==2019) %>%
  summarize(wht_stops=sum(white_stop, na.rm=T),
            blk_stops=sum(black_stop, na.rm=T),
            hisp_stop=sum(hisp_stop, na.rm=T))

#TABLE 3.2
fullset$police <- ifelse( grepl("Police", fullset$agencydescription, fixed=T)==T,1,0)
fullset$sheriff <- ifelse( grepl("Sheriff*", fullset$agencydescription, fixed=T)==T,1,0)

fullset %>%
  group_by(agencydescription) %>%
  mutate(police= ifelse(grepl("Police", agencydescription, fixed=T)==T,1,0),
         sheriff =ifelse(grepl("Sheriff*",agencydescription, fixed=T)==T,1,0)) %>%
  summarise(stops=count(stopid))

       